@@ -10,13 +10,18 @@ import (
 	"gotest.tools/v3/icmd"
 )
 
+const (
+	kb int64 = 1024
+	mb       = kb * kb
+)
+
 func TestCatS3Object(t *testing.T) {
 	t.Parallel()
 
 	const (
 		filename = "file.txt"
 	)
-	contents, expected := getSequentialFileContent()
+	contents, expected := getSequentialFileContent(4 * mb)
 
 	testcases := []struct {
 		name      string
@@ -42,6 +47,31 @@ func TestCatS3Object(t *testing.T) {
 				jsonCheck(true),
 			},
 		},
+		{
+			name: "cat remote object with lower part size and higher concurrency",
+			cmd: []string{
+				"cat",
+				"-p",
+				"1",
+				"-c",
+				"2",
+			},
+			expected: expected,
+		},
+		{
+			name: "cat remote object with json flag lower part size and higher concurrency",
+			cmd: []string{
+				"--json",
+				"cat",
+				"-p",
+				"1",
+				"-c",
+				"2",
+			}, expected: expected,
+			assertOps: []assertOp{
+				jsonCheck(true),
+			},
+		},
 	}
 	for _, tc := range testcases {
 		tc := tc
@@ -86,7 +116,7 @@ func TestCatS3ObjectFail(t *testing.T) {
 				"cat",
 			},
 			expected: map[int]compareFunc{
-				0: match(`ERROR "cat s3://(.*)/prefix/file\.txt": NoSuchKey:`),
+				0: match(`ERROR "cat s3://(.*)/prefix/file\.txt":(.*) not found`),
 			},
 		},
 		{
@@ -97,7 +127,7 @@ func TestCatS3ObjectFail(t *testing.T) {
 				"cat",
 			},
 			expected: map[int]compareFunc{
-				0: match(`{"operation":"cat","command":"cat s3:\/\/(.*)\/prefix\/file\.txt","error":"NoSuchKey:`),
+				0: match(`{"operation":"cat","command":"cat s3:\/\/(.*)\/prefix\/file\.txt","error":"(.*) not found`),
 			},
 			assertOps: []assertOp{
 				jsonCheck(true),
@@ -142,7 +172,6 @@ func TestCatS3ObjectFail(t *testing.T) {
 			cmd := s5cmd(tc.cmd...)
 
 			result := icmd.RunCmd(cmd)
-
 			result.Assert(t, icmd.Expected{ExitCode: 1})
 			assertLines(t, result.Stderr(), tc.expected, tc.assertOps...)
 		})
@@ -200,16 +229,16 @@ func TestCatLocalFileFail(t *testing.T) {
 	}
 }
 
-// getSequentialFileContent creates a string with 64666688 in size (~61.670 MB)
-func getSequentialFileContent() (string, map[int]compareFunc) {
+// getSequentialFileContent creates a string with size bytes in size.
+func getSequentialFileContent(size int64) (string, map[int]compareFunc) {
 	sb := strings.Builder{}
 	expectedLines := make(map[int]compareFunc)
-
-	for i := 0; i < 50000; i++ {
+	totalBytesWritten := int64(0)
+	for i := 0; totalBytesWritten < size; i++ {
 		line := fmt.Sprintf(`{ "line": "%d", "id": "i%d", data: "some event %d" }`, i, i, i)
 		sb.WriteString(line)
 		sb.WriteString("\n")
-
+		totalBytesWritten += int64(len(line))
 		expectedLines[i] = equals(line)
 	}
 
@@ -272,7 +301,6 @@ func TestCatByVersionID(t *testing.T) {
 		cmd = s5cmd("cat", "--version-id", version,
 			fmt.Sprintf("s3://%v/%v", bucket, filename))
 		result = icmd.RunCmd(cmd)
-
 		if diff := cmp.Diff(contents[i], result.Stdout()); diff != "" {
 			t.Errorf("(-want +got):\n%v", diff)
 		}
